<?php

declare(strict_types=1);

namespace Drupal\google_v3_glossary\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Drupal\google_v3_glossary\Traits\GoogleV3GlossaryTrait;

/**
 * Returns responses for google_v3_glossary routes.
 */
final class GlossaryController extends ControllerBase {
  use GoogleV3GlossaryTrait;

  /**
   * Builds the response.
   */
  public function __invoke(): array {
    $build['config_info'] = [
      '#type' => 'item',
      '#markup' => $this->t(
        "Be sure to configure the Google V3 Glossary settings by visiting the <a href='@config_form'>configuration form</a>.",
        ['@config_form' => Url::fromRoute('google_v3_glossary.settings')->toString()]
      ),
    ];

    // Get all available languages.
    $languages = $this->getEnabledLanguages();

    // Create a list of links for each language.
    $items = [];
    foreach ($languages as $langcode => $language) {
      $items[] = [
        '#type' => 'link',
        '#title' => $language,
        '#url' => Url::fromRoute(
          'google_v3_glossary.glossary.language',
          ['langcode' => $langcode]
        ),
      ];
    }

    // Add the bullet list to the build.
    $build['language_list'] = [
      '#theme' => 'item_list',
      '#items' => $items,
      '#title' => $this->t('Available glossaries by language'),
    ];

    return $build;
  }

  /**
   * Gets the title for a language glossary form.
   *
   * @param string $langcode
   *   The language code.
   *
   * @return string
   *   The translated language name.
   */
  public function getLanguageTitle(string $langcode): string {
    $languages = $this->getEnabledLanguages();
    if ($languages[$langcode]) {
      $name = $languages[$langcode];
      return "{$name} Translation Glossary";
    }
    return "{$langcode} Translation Glossary";
  }

}
