<?php

namespace Drupal\google_v3_glossary\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\google_v3_glossary\Traits\GoogleV3GlossaryTrait;

/**
 * Configure Google V3 Glossary settings for this site.
 */
class GoogleV3GlossaryConfigForm extends ConfigFormBase {
  use GoogleV3GlossaryTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'google_v3_glossary_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['google_v3_glossary.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('google_v3_glossary.settings');
    $enabledLanguages = $this->getEnabledLanguages();

    $form['bucket_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Bucket name'),
      '#description' => $this->t('Enter the Google Cloud Storage bucket name for glossaries.'),
      '#default_value' => $config->get('bucket_name'),
      '#required' => TRUE,
    ];

    // Details section for Languages.
    $form['languages'] = [
      '#type' => 'details',
      '#title' => $this->t('Languages'),
      '#open' => TRUE,
    ];

    // For each enabled langiuage add a fiel_path field.
    foreach ($enabledLanguages as $langCode => $langName) {
      $form['languages']['file_path_' . $langCode] = [
        '#type' => 'textfield',
        '#title' => $this->t('File path for @langName', ['@langName' => $langName]),
        '#default_value' => $config->get('file_path_' . $langCode),
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $enabledLanguages = $this->getEnabledLanguages();
    $this->config('google_v3_glossary.settings')
      ->set('bucket_name', $form_state->getValue('bucket_name'))
      ->save();

    foreach ($enabledLanguages as $langCode => $langName) {
      $this->config('google_v3_glossary.settings')
        ->set('file_path_' . $langCode, $form_state->getValue('file_path_' . $langCode))
        ->save();
    }

    parent::submitForm($form, $form_state);
  }

}
